==> aws-java-sdk-emr-1.10.3-sources.jar: com/amazonaws/services/elasticmapreduce/model/InstanceGroupType.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.elasticmapreduce.model;

/**
 * Instance Group Type
 */
public enum InstanceGroupType {
    
    MASTER("MASTER"),
    CORE("CORE"),
    TASK("TASK");

    private String value;

    private InstanceGroupType(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return this.value;
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value
     *            real value
     * @return InstanceGroupType corresponding to the value
     */
    public static InstanceGroupType fromValue(String value) {
        if (value == null || "".equals(value)) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        
        } else if ("MASTER".equals(value)) {
            return InstanceGroupType.MASTER;
        } else if ("CORE".equals(value)) {
            return InstanceGroupType.CORE;
        } else if ("TASK".equals(value)) {
            return InstanceGroupType.TASK;
        } else {
            throw new IllegalArgumentException("Cannot create enum from " + value + " value!");
        }
    }
}

==> aws-java-sdk-emr-1.10.29-sources.jar: com/amazonaws/services/elasticmapreduce/model/InstanceGroupType.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.elasticmapreduce.model;

/**
 * 
 */
public enum InstanceGroupType {

    MASTER("MASTER"),
    CORE("CORE"),
    TASK("TASK");

    private String value;

    private InstanceGroupType(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return this.value;
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value
     *        real value
     * @return InstanceGroupType corresponding to the value
     */
    public static InstanceGroupType fromValue(String value) {
        if (value == null || "".equals(value)) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        } else if ("MASTER".equals(value)) {
            return MASTER;
        } else if ("CORE".equals(value)) {
            return CORE;
        } else if ("TASK".equals(value)) {
            return TASK;
        } else {
            throw new IllegalArgumentException("Cannot create enum from "
                    + value + " value!");
        }
    }
}
